Learn R Programming

orbital (version 0.5.0)

orbital_dt: Convert to data.table code

Description

Returns data.table code that is equivilant to prediction code.

Usage

orbital_dt(x)

Value

data.table code.

Arguments

x

An orbital object.

This function requires dtplyr to be installed to run. The resulting code will likely need to be adopted to your use-case. Most likely by removing the initial copy(data-name) at the start.